@@ -61,14 +61,14 @@ from clu.exporting import (doctrim,
                            determine_name,
                            sysmods,
                            Exporter, ExporterBase, Registry,
-                           path_to_dotpath,
-                           predicates_for_types)
+                           path_to_dotpath)
 
 from clu.sanitizer import sanitize, sanitizers, utf8_encode, utf8_decode
 from clu.version import version_info
 
 from clu.predicates import (negate,
-                            ismetaclass, isclass, isclasstype, metaclass,
+                            ismetaclass, isclass, isclasstype,
+                            metaclass, typeof,
                             noattr, haspyattr, nopyattr,
                             anyattrs, allattrs, noattrs,
                             anypyattrs, allpyattrs, nopyattrs,
@@ -125,10 +125,11 @@ from clu.naming import (determine_module, nameof, moduleof,
                         dotpath_to_prefix, path_to_prefix,
                         split_abbreviations)
 
-from clu.config.base import NamespacedMutableMapping, Flat, Nested
+from clu.config.abc import NAMESPACE_SEP, NamespacedMutableMapping, FlatOrderedSet
+from clu.config.base import Flat, Nested
 from clu.config.env import Env
 from clu.config.filebase import FileName, FileBase
-from clu.config.fieldtypes import ValidationError, hoist, FlatOrderedSet
+from clu.config.fieldtypes import ValidationError, hoist
 from clu.config.fieldtypes import functional_and, functional_set
 from clu.config.fieldtypes import FieldBase
 from clu.config.fieldtypes import fields
@@ -229,7 +230,6 @@ __all__ = ('Image',
            'σ', 'Σ',
            'isdtype', 'isnumpything', 'isnumpytype', 'isnumpythinglist', 'isnumpytypelist',
            'Clamper', 'clamp',
-           'predicates_for_types',
            'version_info',
            'BASEPATH',
            'BUILTINS',
@@ -285,9 +285,10 @@ __all__ = ('Image',
            'determine_name',
            'sysmods',
            'Exporter', 'ExporterBase', 'Registry',
-           'path_to_dotpath', 'predicates_for_types',
+           'path_to_dotpath',
            'negate',
-           'ismetaclass', 'isclass', 'isclasstype', 'metaclass',
+           'ismetaclass', 'isclass', 'isclasstype',
+           'metaclass', 'typeof',
            'noattr', 'haspyattr', 'nopyattr',
            'anyattrs', 'allattrs', 'noattrs',
            'anypyattrs', 'allpyattrs', 'nopyattrs',
@@ -339,9 +340,10 @@ __all__ = ('Image',
            'qualified_import', 'qualified_name_tuple', 'qualified_name',
            'dotpath_to_prefix', 'path_to_prefix',
            'split_abbreviations',
-           'NamespacedMutableMapping', 'Flat', 'Nested',
+           'NAMESPACE_SEP', 'NamespacedMutableMapping', 'FlatOrderedSet',
+           'Flat', 'Nested',
            'Env', 'FileName', 'FileBase',
-           'ValidationError', 'hoist', 'FlatOrderedSet',
+           'ValidationError', 'hoist',
            'functional_and', 'functional_set',
            'FieldBase', 'fields',
            'Schema', 'JsonFile', 'PickleFile', 'TomlFile', 'YamlFile',
